Range-v3: ranges::v3::meta::defer_i< T, C, Is > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::meta::defer_i< T, C, Is > Struct Template Reference

## Description

### template<typename T, template< T...> class C, T... Is>
struct ranges::v3::meta::defer_i< T, C, Is >

A wrapper that defers the instantiation of a template `C` with integral constant parameters `Is` in a `lambda` or `let` expression.

See also
  `defer`

Inheritance diagram for ranges::v3::meta::defer_i< T, C, Is >: